@@ -6,7 +6,7 @@
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; under version 2 of the License.
+ *  the Free Software Foundation; under version 3 of the License.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,12 +14,14 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses>.
+ *
+ *  The Audacious team does not consider modular code linking to
+ *  Audacious or using our public API to be a derived work.
  */
 
-#ifndef GENERIC_H
-#define GENERIC_H
+#ifndef AUDACIOUS_GENERAL_H
+#define AUDACIOUS_GENERAL_H
 
 #include <glib.h>
 
@@ -33,12 +35,9 @@ struct _GeneralPluginData {
 GList *get_general_list(void);
 GList *get_general_enabled_list(void);
 void enable_general_plugin(gint i, gboolean enable);
-void general_about(gint i);
-void general_configure(gint i);
-gboolean general_enabled(gint i);
 gchar *general_stringify_enabled_list(void);
 void general_enable_from_stringified_list(const gchar * list);
 
 extern GeneralPluginData gp_data;
 
-#endif
+#endif /* AUDACIOUS_GENERAL_H */
