@@ -23,6 +23,8 @@
  *  Audacious or using our public API to be a derived work.
  */
 
+/*#define AUD_DEBUG*/
+
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
@@ -37,9 +39,7 @@
 #include <string.h>
 
 #include "platform/smartinclude.h"
-#include "skin.h"
-#include "dock.h"
-#include "hints.h"
+#include "ui_skin.h"
 #include "input.h"
 #include "main.h"
 #include "ui_manager.h"
@@ -48,12 +48,14 @@
 #include "ui_playlist.h"
 #include "util.h"
 #include "output.h"
+#include "equalizer_flow.h"
 
 #include "rcfile.h"
 #include "vfs.h"
 
 #include "images/audacious_eq.xpm"
 
+#include "ui_dock.h"
 #include "ui_skinned_window.h"
 #include "ui_skinned_button.h"
 #include "ui_skinned_horizontal_slider.h"
@@ -111,23 +113,8 @@ equalizer_preset_free(EqualizerPreset * preset)
     g_free(preset);
 }
 
-
-static void
-equalizerwin_set_shape_mask(void)
-{
-    if (cfg.show_wm_decorations)
-        return;
-
-    if (cfg.doublesize == FALSE)
-        gtk_widget_shape_combine_mask(equalizerwin,
-                                      skin_get_mask(bmp_active_skin,
-                                                    SKIN_MASK_EQ), 0, 0);
-    else
-        gtk_widget_shape_combine_mask(equalizerwin, NULL, 0, 0);
-}
-
 void
-equalizerwin_set_doublesize(gboolean ds)
+equalizerwin_set_scaled(gboolean ds)
 {
     gint height;
 
@@ -136,10 +123,9 @@ equalizerwin_set_doublesize(gboolean ds)
     else
         height = 116;
 
-    equalizerwin_set_shape_mask();
-
-    if (ds) {
-        dock_window_resize(GTK_WINDOW(equalizerwin), 550, height * 2, 550, height * 2);
+    if (cfg.scaled) {
+        dock_window_resize(GTK_WINDOW(equalizerwin), 275 * cfg.scale_factor, 
+            height * cfg.scale_factor, 275 * cfg.scale_factor, height * cfg.scale_factor);
     } else {
         dock_window_resize(GTK_WINDOW(equalizerwin), 275, height, 275, height);
     }
@@ -148,8 +134,9 @@ equalizerwin_set_doublesize(gboolean ds)
     for (iter = GTK_FIXED (SKINNED_WINDOW(equalizerwin)->fixed)->children; iter; iter = g_list_next (iter)) {
         GtkFixedChild *child_data = (GtkFixedChild *) iter->data;
         GtkWidget *child = child_data->widget;
-        g_signal_emit_by_name(child, "toggle-double-size");
+        g_signal_emit_by_name(child, "toggle-scaled");
     }
+    gtk_widget_shape_combine_mask(equalizerwin, skin_get_mask(aud_active_skin, SKIN_MASK_EQ + cfg.equalizer_shaded), 0, 0);
 }
 
 void
@@ -157,11 +144,9 @@ equalizerwin_set_shade_menu_cb(gboolean shaded)
 {
     cfg.equalizer_shaded = shaded;
 
-    equalizerwin_set_shape_mask();
-
     if (shaded) {
-        dock_shade(dock_window_list, GTK_WINDOW(equalizerwin),
-                   14 * (EQUALIZER_DOUBLESIZE + 1));
+        dock_shade(get_dock_window_list(), GTK_WINDOW(equalizerwin),
+                   14 * EQUALIZER_SCALE_FACTOR);
         ui_skinned_set_push_button_data(equalizerwin_shade, -1, 3, -1, 47);
         ui_skinned_button_set_skin_index1(equalizerwin_shade, SKIN_EQ_EX);
         ui_skinned_set_push_button_data(equalizerwin_close, 11, 38, 11, 47);
@@ -170,8 +155,8 @@ equalizerwin_set_shade_menu_cb(gboolean shaded)
         gtk_widget_show(equalizerwin_balance);
     }
     else {
-        dock_shade(dock_window_list, GTK_WINDOW(equalizerwin),
-                   116 * (EQUALIZER_DOUBLESIZE + 1));
+        dock_shade(get_dock_window_list(), GTK_WINDOW(equalizerwin),
+                   116 * EQUALIZER_SCALE_FACTOR);
         ui_skinned_set_push_button_data(equalizerwin_shade, -1, 137, -1, 38);
         ui_skinned_button_set_skin_index1(equalizerwin_shade, SKIN_EQMAIN);
         ui_skinned_set_push_button_data(equalizerwin_close, 0, 116, 0, 125);
@@ -179,6 +164,8 @@ equalizerwin_set_shade_menu_cb(gboolean shaded)
         gtk_widget_hide(equalizerwin_volume);
         gtk_widget_hide(equalizerwin_balance);
     }
+
+    gtk_widget_shape_combine_mask(equalizerwin, skin_get_mask(aud_active_skin, SKIN_MASK_EQ + cfg.equalizer_shaded), 0, 0);
 }
 
 static void
@@ -195,13 +182,6 @@ equalizerwin_shade_toggle(void)
     equalizerwin_set_shade(!cfg.equalizer_shaded);
 }
 
-static void
-equalizerwin_raise(void)
-{
-    if (cfg.equalizer_visible)
-        gtk_window_present(GTK_WINDOW(equalizerwin));
-}
-
 void
 equalizerwin_eq_changed(void)
 {
@@ -247,36 +227,21 @@ gboolean
 equalizerwin_press(GtkWidget * widget, GdkEventButton * event,
                    gpointer callback_data)
 {
-    if (event->button == 1 && event->type == GDK_BUTTON_PRESS &&
-        (cfg.easy_move || cfg.equalizer_shaded || event->y < 14)) {
-         equalizerwin_raise();
-         dock_move_press(dock_window_list, GTK_WINDOW(equalizerwin), event,
-                         FALSE);
-    }
-    else if (event->button == 1 && event->type == GDK_2BUTTON_PRESS
+    if (event->button == 1 && event->type == GDK_2BUTTON_PRESS
              && event->y < 14) {
         equalizerwin_set_shade(!cfg.equalizer_shaded);
         if (dock_is_moving(GTK_WINDOW(equalizerwin)))
             dock_move_release(GTK_WINDOW(equalizerwin));
+        return TRUE;
     }
-    else if (event->button == 3) {
+    if (event->button == 3) {
         /*
          * Pop up the main menu a few pixels down to avoid
          * anything to be selected initially.
          */
        ui_manager_popup_menu_show(GTK_MENU(mainwin_general_menu), event->x_root,
                                 event->y_root + 2, 3, event->time);
-    }
-
-    return FALSE;
-}
-
-static gboolean
-equalizerwin_release(GtkWidget * widget,
-                     GdkEventButton * event, gpointer callback_data)
-{
-    if (dock_is_moving(GTK_WINDOW(equalizerwin))) {
-        dock_move_release(GTK_WINDOW(equalizerwin));
+       return TRUE;
     }
 
     return FALSE;
@@ -343,13 +308,13 @@ equalizerwin_read_presets(const gchar * basename)
     /* START mod: add check for the default presets locate in system path ({prefix}/share/audacious)
        by Massimo Cavalleri (submax) */
 
-    filename = g_build_filename(bmp_paths[BMP_PATH_USER_DIR], basename, NULL);
+    filename = g_build_filename(aud_paths[BMP_PATH_USER_DIR], basename, NULL);
 
-    if ((rcfile = bmp_rcfile_open(filename)) == NULL) {
+    if ((rcfile = aud_rcfile_open(filename)) == NULL) {
         g_free(filename);
         // DATA_DIR = "{prefix}/share/audacious" ; example is "/usr/share/audacious"
         filename = g_build_filename(DATA_DIR, basename, NULL);
-        if ((rcfile = bmp_rcfile_open(filename)) == NULL) {
+        if ((rcfile = aud_rcfile_open(filename)) == NULL) {
            g_free(filename);
            return NULL;
         }
@@ -363,14 +328,14 @@ equalizerwin_read_presets(const gchar * basename)
         gchar section[21];
 
         g_snprintf(section, sizeof(section), "Preset%d", p++);
-        if (bmp_rcfile_read_string(rcfile, "Presets", section, &name)) {
+        if (aud_rcfile_read_string(rcfile, "Presets", section, &name)) {
             preset = g_new0(EqualizerPreset, 1);
             preset->name = name;
-            bmp_rcfile_read_float(rcfile, name, "Preamp", &preset->preamp);
+            aud_rcfile_read_float(rcfile, name, "Preamp", &preset->preamp);
             for (i = 0; i < 10; i++) {
                 gchar band[7];
                 g_snprintf(band, sizeof(band), "Band%d", i);
-                bmp_rcfile_read_float(rcfile, name, band, &preset->bands[i]);
+                aud_rcfile_read_float(rcfile, name, band, &preset->bands[i]);
             }
             list = g_list_prepend(list, preset);
         }
@@ -378,7 +343,7 @@ equalizerwin_read_presets(const gchar * basename)
             break;
     }
     list = g_list_reverse(list);
-    bmp_rcfile_free(rcfile);
+    aud_rcfile_free(rcfile);
     return list;
 }
 
@@ -539,9 +504,9 @@ equalizerwin_create_window(void)
     gtk_window_set_role(GTK_WINDOW(equalizerwin), "equalizer");
     gtk_window_set_resizable(GTK_WINDOW(equalizerwin), FALSE);
 
-    if (cfg.doublesize && cfg.eq_doublesize_linked) {
-        width *= 2;
-        height *= 2;
+    if (cfg.scaled && cfg.eq_scaled_linked) {
+        width *= cfg.scale_factor;
+        height *= cfg.scale_factor;
     }
 
     gtk_widget_set_size_request(equalizerwin, width, height);
@@ -551,7 +516,7 @@ equalizerwin_create_window(void)
                                  GTK_WINDOW(mainwin));
     gtk_window_set_skip_taskbar_hint(GTK_WINDOW(equalizerwin), TRUE);
 
-    icon = gdk_pixbuf_new_from_xpm_data((const gchar **) bmp_eq_icon);
+    icon = gdk_pixbuf_new_from_xpm_data((const gchar **) audacious_eq_icon);
     gtk_window_set_icon(GTK_WINDOW(equalizerwin), icon);
     g_object_unref(icon);
 
@@ -565,8 +530,6 @@ equalizerwin_create_window(void)
                      G_CALLBACK(equalizerwin_delete), NULL);
     g_signal_connect(equalizerwin, "button_press_event",
                      G_CALLBACK(equalizerwin_press), NULL);
-    g_signal_connect(equalizerwin, "button_release_event",
-                     G_CALLBACK(equalizerwin_release), NULL);
     g_signal_connect(equalizerwin, "key_press_event",
                      G_CALLBACK(equalizerwin_keypress), NULL);
 }
@@ -602,9 +565,9 @@ void
 equalizerwin_real_show(void)
 {
     gtk_window_move(GTK_WINDOW(equalizerwin), cfg.equalizer_x, cfg.equalizer_y);
-    if (cfg.doublesize && cfg.eq_doublesize_linked)
-        gtk_widget_set_size_request(equalizerwin, 550,
-                                    (cfg.equalizer_shaded ? 28 : 232));
+    if (cfg.scaled && cfg.eq_scaled_linked)
+        gtk_widget_set_size_request(equalizerwin, 275 * cfg.scale_factor,
+                                    ((cfg.equalizer_shaded ? 14 : 116) * cfg.scale_factor));
     else
         gtk_widget_set_size_request(equalizerwin, 275,
                                     (cfg.equalizer_shaded ? 14 : 116));
@@ -663,26 +626,26 @@ equalizerwin_write_preset_file(GList * list, const gchar * basename)
     RcFile *rcfile;
     GList *node;
 
-    rcfile = bmp_rcfile_new();
+    rcfile = aud_rcfile_new();
     p = 0;
     for (node = list; node; node = g_list_next(node)) {
         preset = node->data;
         tmp = g_strdup_printf("Preset%d", p++);
-        bmp_rcfile_write_string(rcfile, "Presets", tmp, preset->name);
+        aud_rcfile_write_string(rcfile, "Presets", tmp, preset->name);
         g_free(tmp);
-        bmp_rcfile_write_float(rcfile, preset->name, "Preamp",
+        aud_rcfile_write_float(rcfile, preset->name, "Preamp",
                                preset->preamp);
         for (i = 0; i < 10; i++) {
             tmp = g_strdup_printf("Band%d\n", i);
-            bmp_rcfile_write_float(rcfile, preset->name, tmp,
+            aud_rcfile_write_float(rcfile, preset->name, tmp,
                                    preset->bands[i]);
             g_free(tmp);
         }
     }
 
-    filename = g_build_filename(bmp_paths[BMP_PATH_USER_DIR], basename, NULL);
-    bmp_rcfile_write(rcfile, filename);
-    bmp_rcfile_free(rcfile);
+    filename = g_build_filename(aud_paths[BMP_PATH_USER_DIR], basename, NULL);
+    aud_rcfile_write(rcfile, filename);
+    aud_rcfile_free(rcfile);
     g_free(filename);
 }
 
@@ -789,76 +752,101 @@ equalizerwin_delete_selected_presets(GtkTreeView *view, gchar *filename)
     }
 }
 
-
 static GList *
 import_winamp_eqf(VFSFile * file)
 {
     gchar header[31];
-    gchar name[257];
     gchar bands[11];
     gint i = 0;
+    EqualizerPreset *preset = NULL;
     GList *list = NULL;
-    EqualizerPreset *preset;
+    GtkWidget *dialog;
+    gchar *realfn;
+    gchar preset_name[0xb4];
 
     vfs_fread(header, 1, 31, file);
-    if (!strncmp(header, "Winamp EQ library file v1.1", 27)) {
-        while (vfs_fread(name, 1, 257, file)) {
-            preset = equalizer_preset_new(name);
-            preset->preamp = 20.0 - ((bands[10] * 40.0) / 64);
+    if (strncmp(header, "Winamp EQ library file v1.1", 27)) goto error;
 
-            vfs_fread(bands, 1, 11, file);
+    AUDDBG("The EQF header is OK\n");
 
-            for (i = 0; i < 10; i++)
-                preset->bands[i] = 20.0 - ((bands[i] * 40.0) / 64);
+    if (vfs_fseek(file, 0x1f, SEEK_SET) == -1) goto error;
 
-            list = g_list_prepend(list, preset);
-        }
+    while (vfs_fread(preset_name, 1, 0xb4, file) == 0xb4) {
+        AUDDBG("The preset name is '%s'\n", preset_name);
+        vfs_fseek(file, 0x4d, SEEK_CUR); /* unknown crap --asphyx */
+        if (vfs_fread(bands, 1, 11, file) != 11) break;
+
+        preset = equalizer_preset_new(preset_name);
+        /*this was divided by 63, but shouldn't it be 64? --majeru*/
+        preset->preamp = EQUALIZER_MAX_GAIN - ((bands[10] * EQUALIZER_MAX_GAIN * 2) / 64.0);
+
+        for (i = 0; i < 10; i++)
+            preset->bands[i] = EQUALIZER_MAX_GAIN - ((bands[i] * EQUALIZER_MAX_GAIN * 2) / 64.0);
+        
+        list = g_list_prepend(list, preset);
     }
-
+    
     list = g_list_reverse(list);
+    if (list == NULL) goto error;
+
     return list;
+
+error:
+    realfn = g_filename_from_uri(file->uri, NULL, NULL);
+    dialog = gtk_message_dialog_new (GTK_WINDOW(mainwin),
+                                     GTK_DIALOG_DESTROY_WITH_PARENT,
+                                     GTK_MESSAGE_ERROR,
+                                     GTK_BUTTONS_CLOSE,
+                                     _("Error importing Winamp EQF file '%s'"),
+                                     realfn);
+    gtk_dialog_run (GTK_DIALOG (dialog));
+    gtk_widget_destroy (dialog);
+    g_free(realfn);
+    return NULL;
+}
+
+static void
+free_cb (gpointer data, gpointer user_data)
+{
+    equalizer_preset_free((EqualizerPreset*)data);
 }
 
 static void
 equalizerwin_read_winamp_eqf(VFSFile * file)
 {
-    gchar header[31];
-    guchar bands[11];
+    GList *presets;
     gint i;
 
-    vfs_fread(header, 1, 31, file);
+    if ((presets = import_winamp_eqf(file)) == NULL)
+        return;
 
-    if (!strncmp(header, "Winamp EQ library file v1.1", 27)) {
-        /* Skip name */
-        if (vfs_fseek(file, 257, SEEK_CUR) == -1)
-            return;
+    /* just get the first preset --asphyx */
+    EqualizerPreset *preset = (EqualizerPreset*)presets->data;
+    ui_skinned_equalizer_slider_set_position(equalizerwin_preamp,
+                                             preset->preamp);
 
-        if (vfs_fread(bands, 1, 11, file) != 11)
-            return;
+    for (i = 0; i < 10; i++)
+        ui_skinned_equalizer_slider_set_position(equalizerwin_bands[i],
+                                                 preset->bands[i]);
 
-        ui_skinned_equalizer_slider_set_position(equalizerwin_preamp,
-                              20.0 - ((bands[10] * 40.0) / 63.0));
-
-        for (i = 0; i < 10; i++)
-            ui_skinned_equalizer_slider_set_position(equalizerwin_bands[i],
-                                  20.0 - ((bands[i] * 40.0) / 64.0));
-    }
+    g_list_foreach(presets, free_cb, NULL);
+    g_list_free(presets);
 
     equalizerwin_eq_changed();
 }
 
 static void
-equalizerwin_read_bmp_preset(RcFile * rcfile)
+equalizerwin_read_aud_preset(RcFile * rcfile)
 {
     gfloat val;
     gint i;
 
-    if (bmp_rcfile_read_float(rcfile, "Equalizer preset", "Preamp", &val))
+    if (aud_rcfile_read_float(rcfile, "Equalizer preset", "Preamp", &val))
         ui_skinned_equalizer_slider_set_position(equalizerwin_preamp, val);
     for (i = 0; i < 10; i++) {
         gchar tmp[7];
         g_snprintf(tmp, sizeof(tmp), "Band%d", i);
-        if (bmp_rcfile_read_float(rcfile, "Equalizer preset", tmp, &val))
+        if (aud_rcfile_read_float(rcfile, "Equalizer preset", tmp, &val))
             ui_skinned_equalizer_slider_set_position(equalizerwin_bands[i], val);
     }
     equalizerwin_eq_changed();
@@ -1013,24 +1001,39 @@ load_preset_file(const gchar *filename)
 {
     RcFile *rcfile;
 
-    if ((rcfile = bmp_rcfile_open(filename)) != NULL) {
-        equalizerwin_read_bmp_preset(rcfile);
-        bmp_rcfile_free(rcfile);
+    if ((rcfile = aud_rcfile_open(filename)) != NULL) {
+        equalizerwin_read_aud_preset(rcfile);
+        aud_rcfile_free(rcfile);
     }
 }
 
+static VFSFile *
+open_vfs_file(const gchar *filename, const gchar *mode)
+{
+    VFSFile *file;
+    GtkWidget *dialog;
+
+    if (!(file = vfs_fopen(filename, mode))) {
+        dialog = gtk_message_dialog_new (GTK_WINDOW (mainwin),
+                                         GTK_DIALOG_DESTROY_WITH_PARENT,
+                                         GTK_MESSAGE_ERROR,
+                                         GTK_BUTTONS_CLOSE,
+                                         "Error loading file '%s'",
+                                         filename);
+        gtk_dialog_run (GTK_DIALOG (dialog));
+        gtk_widget_destroy (dialog);
+    }
+
+    return file;
+}
+
 static void
 load_winamp_file(const gchar * filename)
 {
     VFSFile *file;
-    gchar *tmp;
 
-    if (!(file = vfs_fopen(filename, "rb"))) {
-        tmp = g_strconcat("Failed to load WinAmp file: ",filename,"\n",NULL);
-        report_error(tmp);
-        g_free(tmp);
+    if (!(file = open_vfs_file(filename, "rb")))
         return;
-    }
 
     equalizerwin_read_winamp_eqf(file);
     vfs_fclose(file);
@@ -1040,17 +1043,13 @@ static void
 import_winamp_file(const gchar * filename)
 {
     VFSFile *file;
-    gchar *tmp;
+    GList *list;
 
-    if (!(file = vfs_fopen(filename, "rb"))) {
-        tmp = g_strconcat("Failed to import WinAmp file: ",filename,"\n",NULL);
-        report_error(tmp);
-        g_free(tmp);
+    if (!(file = open_vfs_file(filename, "rb")) ||
+        !(list = import_winamp_eqf(file)))
         return;
-    }
 
-    equalizer_presets = g_list_concat(equalizer_presets,
-                                      import_winamp_eqf(file));
+    equalizer_presets = g_list_concat(equalizer_presets, list);
     equalizerwin_write_preset_file(equalizer_presets, "eq.preset");
 
     vfs_fclose(file);
@@ -1062,19 +1061,19 @@ save_preset_file(const gchar * filename)
     RcFile *rcfile;
     gint i;
 
-    rcfile = bmp_rcfile_new();
-    bmp_rcfile_write_float(rcfile, "Equalizer preset", "Preamp",
+    rcfile = aud_rcfile_new();
+    aud_rcfile_write_float(rcfile, "Equalizer preset", "Preamp",
                            ui_skinned_equalizer_slider_get_position(equalizerwin_preamp));
 
     for (i = 0; i < 10; i++) {
         gchar tmp[7];
         g_snprintf(tmp, sizeof(tmp), "Band%d", i);
-        bmp_rcfile_write_float(rcfile, "Equalizer preset", tmp,
+        aud_rcfile_write_float(rcfile, "Equalizer preset", tmp,
                                ui_skinned_equalizer_slider_get_position(equalizerwin_bands[i]));
     }
 
-    bmp_rcfile_write(rcfile, filename);
-    bmp_rcfile_free(rcfile);
+    aud_rcfile_write(rcfile, filename);
+    aud_rcfile_free(rcfile);
 }
 
 static void
@@ -1085,24 +1084,19 @@ save_winamp_file(const gchar * filename)
     gchar name[257];
     gint i;
     guchar bands[11];
-    gchar *tmp;
 
-    if (!(file = vfs_fopen(filename, "wb"))) {
-        tmp = g_strconcat("Failed to save WinAmp file: ",filename,"\n",NULL);
-        report_error(tmp);
-        g_free(tmp);
+    if (!(file = open_vfs_file(filename, "wb")))
         return;
-    }
 
     vfs_fwrite("Winamp EQ library file v1.1\x1a!--", 1, 31, file);
 
     memset(name, 0, 257);
-    strcpy(name, "Entry1");
+    g_strlcpy(name, "Entry1", 257);
     vfs_fwrite(name, 1, 257, file);
 
     for (i = 0; i < 10; i++)
-        bands[i] = 63 - (((ui_skinned_equalizer_slider_get_position(equalizerwin_bands[i]) + 20) * 63) / 40);
-    bands[10] = 63 - (((ui_skinned_equalizer_slider_get_position(equalizerwin_preamp) + 20) * 63) / 40);
+        bands[i] = 63 - (((ui_skinned_equalizer_slider_get_position(equalizerwin_bands[i]) + EQUALIZER_MAX_GAIN) * 63) / EQUALIZER_MAX_GAIN / 2);
+    bands[10] = 63 - (((ui_skinned_equalizer_slider_get_position(equalizerwin_preamp) + EQUALIZER_MAX_GAIN) * 63) / EQUALIZER_MAX_GAIN / 2);
     vfs_fwrite(bands, 1, 11, file);
 
     vfs_fclose(file);
@@ -1233,10 +1227,10 @@ equalizerwin_load_auto_preset(const gchar * filename)
 
     /* First try to find a per file preset file */
     if (strlen(cfg.eqpreset_extension) > 0 &&
-        (rcfile = bmp_rcfile_open(presetfilename)) != NULL) {
+        (rcfile = aud_rcfile_open(presetfilename)) != NULL) {
         g_free(presetfilename);
-        equalizerwin_read_bmp_preset(rcfile);
-        bmp_rcfile_free(rcfile);
+        equalizerwin_read_aud_preset(rcfile);
+        aud_rcfile_free(rcfile);
         return;
     }
 
@@ -1249,9 +1243,9 @@ equalizerwin_load_auto_preset(const gchar * filename)
 
     /* Try to find a per directory preset file */
     if (strlen(cfg.eqpreset_default_file) > 0 &&
-        (rcfile = bmp_rcfile_open(presetfilename)) != NULL) {
-        equalizerwin_read_bmp_preset(rcfile);
-        bmp_rcfile_free(rcfile);
+        (rcfile = aud_rcfile_open(presetfilename)) != NULL) {
+        equalizerwin_read_aud_preset(rcfile);
+        aud_rcfile_free(rcfile);
     }
     else if (!equalizerwin_load_preset
              (equalizer_auto_presets, g_basename(filename))) {
@@ -1345,14 +1339,14 @@ void
 action_equ_load_preset_file(void)
 {
     GtkWidget *dialog;
-    gchar *filename;
+    gchar *file_uri;
 
     dialog = make_filebrowser(Q_("Load equalizer preset"), FALSE);
     if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
     {
-        filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-        load_preset_file(filename);
-        g_free(filename);
+        file_uri = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(dialog));
+        load_preset_file(file_uri);
+        g_free(file_uri);
     }
     gtk_widget_destroy(dialog);
 }
@@ -1361,14 +1355,14 @@ void
 action_equ_load_preset_eqf(void)
 {
     GtkWidget *dialog;
-    gchar *filename;
+    gchar *file_uri;
 
     dialog = make_filebrowser(Q_("Load equalizer preset"), FALSE);
     if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
     {
-        filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-        load_winamp_file(filename);
-        g_free(filename);
+        file_uri = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(dialog));
+        load_winamp_file(file_uri);
+        g_free(file_uri);
     }
     gtk_widget_destroy(dialog);
 }
@@ -1377,14 +1371,14 @@ void
 action_equ_import_winamp_presets(void)
 {
     GtkWidget *dialog;
-    gchar *filename;
+    gchar *file_uri;
 
     dialog = make_filebrowser(Q_("Load equalizer preset"), FALSE);
     if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
     {
-        filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-        import_winamp_file(filename);
-        g_free(filename);
+        file_uri = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(dialog));
+        import_winamp_file(file_uri);
+        g_free(file_uri);
     }
     gtk_widget_destroy(dialog);
 }
@@ -1444,16 +1438,16 @@ void
 action_equ_save_preset_file(void)
 {
     GtkWidget *dialog;
-    gchar *filename;
+    gchar *file_uri;
     gchar *songname;
     Playlist *playlist = playlist_get_active();
 
     dialog = make_filebrowser(Q_("Save equalizer preset"), TRUE);
     if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
     {
-        filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-        save_preset_file(filename);
-        g_free(filename);
+        file_uri = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(dialog));
+        save_preset_file(file_uri);
+        g_free(file_uri);
     }
 
     songname = playlist_get_filename(playlist, playlist_get_position(playlist));
@@ -1473,14 +1467,14 @@ void
 action_equ_save_preset_eqf(void)
 {
     GtkWidget *dialog;
-    gchar *filename;
+    gchar *file_uri;
 
     dialog = make_filebrowser(Q_("Save equalizer preset"), TRUE);
     if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
     {
-        filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-        save_winamp_file(filename);
-        g_free(filename);
+        file_uri = gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(dialog));
+        save_winamp_file(file_uri);
+        g_free(file_uri);
     }
     gtk_widget_destroy(dialog);
 }
